@@ -122,10 +122,14 @@ class PubSub(object):
         if not emit:
             return
 
-        self.connection = redis.StrictRedis(host=self.host, port=self.port, db=self.database)
-        self.pubsub = self.connection.pubsub()
-        self.connection.publish(channel=event, message=message_str)
-        self.pubsub.close()
+        try:
+            self.connection = redis.StrictRedis(host=self.host, port=self.port, db=self.database)
+            self.pubsub = self.connection.pubsub()
+            self.connection.publish(channel=event, message=message_str)
+            self.pubsub.close()
+        except Exception as e:
+            logger.debug(e)
+            pass
 
         if self.enable_kafka:
             for emit_prefix in self.kafka_emit_prefixes:
